<?php
$lang['0_product'] = 'Toode';
$lang['1_service'] = 'Teenus';
$lang['2_discount'] = 'Soodustus';
$lang['3_shipping'] = 'Saatmine';
$lang['4_tax'] = 'Maks';
$lang['addedit_billingform_template'] = 'Add/Edit Billing Form Template';
$lang['addedit_completion_template'] = 'Add/Edit Completion Template';
$lang['addedit_confirmorder_template'] = 'Add/Edit Confirm Order Template';
$lang['addedit_gateway_complete_template'] = 'Add/Edit Gateway Complete Template';
$lang['addedit_invoice_template'] = 'Add/Edit Invoice Template';
$lang['addedit_paymentform_template'] = 'Add/Edit Payment Form Template';
$lang['address1'] = 'Aadressi rida 1';
$lang['address2'] = 'Aadressi rida 2';
$lang['address_handling'] = 'Addressi k&auml;itlemine';
$lang['add_msg_template'] = 'Add a New Message Template';
$lang['admin_email_addresses'] = 'Komaga eraldatud adminni emailiaadresside nimekiri, mida kasutada kui uus tellimus on sisestatud';
$lang['admin_email_template'] = 'Admin Email Template';
$lang['amount'] = 'Kogus';
$lang['amt_due'] = 'Amt. Due';
$lang['any'] = 'Suvaline';
$lang['ask_delete'] = 'Oled sa kindel, et soovid selle eseme kustutada?';
$lang['ask_delete_order'] = 'Oled sa kindel, et soovid kustutada selle tellimuse? Tavaliselt ei ole soovitatud tellimusi kustutada.';
$lang['ask_delete_payment'] = 'Oled sa kindel, et soovid j&auml;&auml;davalt eemaldada k&otilde;ik kirjed selle makse kohta?';
$lang['ask_edit_billing'] = 'Oled sa kindel, et soovid muuta arve informatsiooni selle tellimuse kohta?';
$lang['ask_manual_payment'] = 'Oled sa kindel, et soovid t&ouml;&ouml;delda manuaalset makset krediit kaardile selle summa kohta?';
$lang['ask_saveprefs'] = 'Oled sa kindel, et soovid muuta selle mooduli seadeid?\nEttevaatust, valed seaded v&otilde;ivad l&otilde;hkuda t&ouml;&ouml;tava veebilehe.';
$lang['ask_setorderstatus'] = 'V&otilde;imalik tellimuse oleku muutus on tuvastatud, kas sa soovid seada staatuseks: ';
$lang['back'] = 'Tagasi';
$lang['back_to_orders'] = 'Tagasi tellimuste juurde';
$lang['backorder'] = 'Tagasi saadetud';
$lang['balancedue'] = 'Deebetsaldo (osaliselt makstud)';
$lang['bill_to'] = 'Arve';
$lang['billing_address'] = 'Arve aadress';
$lang['billing_form_templates'] = 'Billing Form Templates';
$lang['billing_info'] = 'Arve informatsioon';
$lang['body'] = 'S&otilde;numi keha';
$lang['cancel'] = 'T&uuml;hista';
$lang['cancelled'] = 'T&uuml;histatud';
$lang['captcha_title'] = 'Captcha Text';
$lang['cart_module'] = 'Cart Module';
$lang['cart_settings'] = 'Cart Settings';
$lang['cash'] = 'Cash';
$lang['cc_AMEX'] = 'American Express';
$lang['cc_Discover'] = 'Discover';
$lang['cc_MasterCard'] = 'Mastercard';
$lang['cc_Visa'] = 'Visa';
$lang['city'] = 'Linn';
$lang['completed'] = 'L&otilde;petatud';
$lang['completion_templates'] = 'Completion Templates';
$lang['confirmed'] = 'Kinnitatud';
$lang['confirm_order'] = 'Kinnita oma tellimus';
$lang['confirmation_form_templates'] = 'Confirmation Form Templates';
$lang['confirmation_num'] = 'Kinnituse number';
$lang['country'] = 'Riik';
$lang['coupon_code'] = 'Kupongi kood';
$lang['created'] = 'Loodud';
$lang['create_invoice'] = 'Loo arve sellele tellimusele';
$lang['create_invoice_for'] = 'Loo arve tellimusele %s';
$lang['creditcard'] = 'Credit Card';
$lang['creditcard_expiry'] = 'CreditCard Expiry Date';
$lang['creditcard_number'] = 'CreditCard Number';
$lang['creditcard_type'] = 'CreditCard Type';
$lang['creditcard_verifycode'] = 'Verification Code';
$lang['customer_name'] = 'Kliendi nimi';
$lang['date'] = 'Kuup&auml;ev';
$lang['default_templates'] = 'Default Templates';
$lang['delete'] = 'Kustuta';
$lang['description'] = 'Kirjeldus';
$lang['destinations'] = 'Sihtkohad';
$lang['details'] = 'Detailid';
$lang['dflt_billingform_template'] = 'Default Billing Form Template';
$lang['dflt_confirmorder_template'] = 'Default Confirm Order Form Template';
$lang['dflt_completion_template'] = 'Default Completion Template';
$lang['dflt_gateway_complete_template'] = 'Default &quot;Gateway Transaction Complete&quot; Template';
$lang['dflt_invoice_message'] = 'T&auml;name ostlemast lehel {sitename}.';
$lang['dflt_invoice_template'] = 'Default Invoice Template';
$lang['dflt_paymentform_template'] = 'Default Payment Form Template';
$lang['discount'] = 'Soodustus';
$lang['edit'] = 'Muuda';
$lang['edit_billing_info'] = 'Muuda arve informatsiooni';
$lang['email'] = 'Email';
$lang['email_address'] = 'Emaili aadress';
$lang['email_invoice'] = 'Emaili see arve kliendile ja volitatud adminnidele';
$lang['email_sent_to'] = 'Email saadetud ';
$lang['email_subject'] = 'Emaili pealkiri';
$lang['error_badcaptcha'] = 'The captcha value supplied was incorrect';
$lang['error_creditcard_expired'] = 'This credit card is expired';
$lang['error_encryption_problem'] = 'A problem occurred encrypting or decrypting data';
$lang['error_gateway_invalid_data'] = 'Could not confirm data validity from payment gateway module';
$lang['error_insufficientparams'] = 'N&otilde;utud parameeter oli puudu';
$lang['error_invalid_address'] = 'Sisestatud aadress on vale (palun veenduge, et te t&auml;itsite k&otilde;ik n&otilde;utud v&auml;ljad korrektselt)';
$lang['error_invalidfield'] = 'J&auml;rgnev v&auml;li on vale: %s';
$lang['error_invalidgateway'] = 'The selected gateway module is invalid for this purpose';
$lang['error_missingshippinginfo'] = 'Ebapiisav saatmise informatsioon sisestatud';
$lang['error_namexists'] = 'Sellise nimega ese eksisteerib juba';
$lang['error_nocartmodule'] = 'Could not find a Cart module.  Please make sure that a cart module is installed, and selected in the Products module preferences.';
$lang['error_noemailaddress'] = 'No email address has been associated with this userid';
$lang['error_nofeumodule'] = 'Could not find the FrontEndUsers module';
$lang['error_nopaymentgateway'] = 'No payment gateway specified';
$lang['error_noproductsmodule'] = 'Could not find the Products module';
$lang['error_norequiredgroup'] = 'Please set a required membership group in the preferences tab';
$lang['error_notloggedin'] = 'The user is not logged in <em>(or not a member of the required group)</em>';
$lang['error_orderinvalid'] = 'There is a problem with this order (the information is inconsistent)';
$lang['error_ordernotfound'] = 'The requested order could not be found';
$lang['error_orderprocessing'] = 'An error occurred while processing this order (soft fail)';
$lang['error_paymentnotfound'] = 'The specified payment could not be found';
$lang['error_requiressl'] = 'The gateway selected for use on this site requires a secure connection, which is not established yet';
$lang['error_retrieve_data'] = 'A problem occurred when trying to retrieve pertinent information from the database';
$lang['error_save'] = 'Error Saving a data item: %s';
$lang['error_security_key'] = 'The encryption key for this transaction could not be retrieved';
$lang['error_paymentgateway_incompatible'] = 'The selected payment gateway is incompatible with this order processing module.  Please contact the site administrator';
$lang['error_permissiondenied'] = 'Permission Denied';
$lang['error_unknownstatus'] = 'Received an unknown status from the payment gateway';
$lang['error_usernotingroup'] = 'The currently logged in user is not a member of the required group';
$lang['fax'] = 'Faks';
$lang['filter'] = 'Filtreeri';
$lang['first_name'] = 'Eesnimi';
$lang['firstpage'] = '<<';
$lang['friendlyname'] = 'Tellimuste haldur';
$lang['from'] = 'From';
$lang['gateway_module'] = 'Payment Gateway Module';
$lang['gateway_complete_templates'] = 'Gateway Complete Templates';
$lang['gateway_failure_message'] = 'Sinu tehingut ei l&otilde;petatud. Tegevus oli kas t&uuml;histatud v&otilde;i m&otilde;ni muu viga ilmnes. Palun kontrolli oma makse informatsiooni ja proovi uuesti. Sinu ostukorv t&uuml;hjendati sinu turvalisuse ja mugavuse huvides. T&auml;name Teid oma aja eest.';
$lang['general_settings'] = '&Uuml;ldised seaded';
$lang['get_address_from_feu'] = 'Kasuta kliendi profiili';
$lang['help_param_nocaptcha'] = 'If this parameter is set, captcha will be turned off';
$lang['help_param_template'] = 'Specify a non default template to use for the default action';
$lang['hold'] = 'Ootel';
$lang['html'] = 'HTML';
$lang['html_email'] = 'Send Email in HTML Format';
$lang['id'] = 'Id';
$lang['incomplete'] = 'L&otilde;petamata (osaliselt postitatud)';
$lang['info_admin_invoice_template'] = 'Select a template that will be used for the printable invoice popup display when managing an order';
$lang['info_adminemail_template'] = 'This template controls the layout and content of the email that is sent to the authorized administrator when a new order is submitted';
$lang['info_allow_creditcard_entry'] = 'Some payment gateways require the user to enter credit card information on your site before submitting that information to the payment processing engine.  Credit Card information will be temporarily stored in an encrypted format until processing is complete or cancelled.  Periodic cleaning of the temporary information will ensure that this information is not retained on your server, unless you enable the option to store credit card information <em>(not recommended)</em>';
$lang['info_billingpage'] = '<strong>Note:</strong> This preference, and the others like it are used to allow the administrator to use different CMSMS pages for the different forms.  If &quot;none&quot; is specified, then the current page will be used.';
$lang['info_ccprocessing_module'] = 'This module is used for manual credit card processing';
$lang['info_coupon_code'] = 'Sisesta kupongi kood v&otilde;imalikuks soodustuseks';
$lang['info_default_templates'] = 'This form controls the content of the template when you click &#039;New Template&#039; in the &#039;Confirmation Form Templates&#039; tab.  Editing the text here will have no immediate effect on the appearance of your site';
$lang['info_encryption_key'] = 'This key is randomly generated when the module is installed.  Use caution when changing this value if there are already orders in the system.';
$lang['info_forcessl'] = '<strong>Note: Recommended</strong>.  If you are allowing customers to enter credit card information, you should enable this option and ensure that you have properly configured your site for SSL access to ensure that the transmission of credit card information is done over an encrypted connection.';
$lang['info_gateway_description'] = 'This information is sent to the payment gateway for each transaction, and may be used for information such as the name that shows up to clients on their credit card statements';
$lang['info_invoicepage'] = '<strong>Note:</strong> This page is also used as the success and failure page for payment gateways';
$lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
$lang['info_order_notes'] = 'Sisesta m&otilde;ned spetsiaalsed m&auml;rkmed selle tellimuse juurde';
$lang['info_skip_invoice_page'] = 'When allowing users to specify payment information,<br/>should they then procede to the invoice page,<br/>or directly to the transaction completion page?';
$lang['info_store_creditcard_data'] = '<strong>Note: <span style=&quot;color: red;&quot;>Not Recommended</span></strong> This option stores the user entered credit card information in the database for later use in the admin panel.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
$lang['info_useremail_template'] = 'This template controls the layout and content of the email that is sent to the user when a new order is submitted';
$lang['info_use_integer'] = 'Kasuta ainult t&auml;isarvulisi v&auml;&auml;rtuseid';
$lang['interval_oneday'] = 'p&auml;eva jooksul';
$lang['interval_onemonth'] = 'kuu jooksul';
$lang['interval_onequarter'] = 'kvartali jooksul';
$lang['interval_oneweek'] = 'n&auml;dala jooksul';
$lang['interval_oneyear'] = 'aasta jooksul';
$lang['interval_twoweeks'] = 'kahe n&auml;dala jooksul';
$lang['invoice'] = 'Arve';
$lang['invoiced'] = 'Arve saadetud';
$lang['invoice_settings'] = 'Arve seaded';
$lang['invoice_templates'] = 'Invoice Templates';
$lang['items'] = 'Esemed';
$lang['last_name'] = 'Perekonna nimi';
$lang['last_modified'] = 'Viimati muudetud';
$lang['lastpage'] = '>>';
$lang['lbl_back'] = 'Tagasi';
$lang['lbl_templates'] = 'Templates';
$lang['message'] = 'S&otilde;num';
$lang['message_templates'] = 'Message Templates';
$lang['method'] = 'Meetod';
$lang['moddescription'] = 'A simple order processing module';
$lang['modified'] = 'Muudetud';
$lang['msg_order_cancelled'] = 'Tellimus %s t&uuml;histatud v&otilde;i tagasi l&uuml;katud';
$lang['msg_order_error'] = 'Error encountered for order %s';
$lang['msg_order_payment'] = 'Makse laekunud tellimuse %s jaoks.';
$lang['msg_order_pending'] = 'Order status changed to &quot;Pending&quot; on %s';
$lang['msg_order_setbackwards'] = 'Attempted to set status of order %s backwards from PAID to PENDING';
$lang['msg_async_transaction'] = 'Handled Async Transcation %s for order %s';
$lang['msg_payment_removed'] = 'Payment removed from the order';
$lang['name'] = 'Nimi';
$lang['net'] = 'Neto';
$lang['net_price'] = 'Neto hind';
$lang['new_order_submitted'] = 'Uus tellimus on sisestatud';
$lang['next'] = 'Edasi';
$lang['nextpage'] = '>';
$lang['no'] = 'Ei';
$lang['no_items_in_cart'] = 'Sinu ostukorv on t&uuml;hi. Palun lisa m&otilde;ned esemed enne kassasse minemist.';
$lang['none'] = 'Pole';
$lang['notcancelledshipped'] = 'Suvalised, v&auml;lja arvatud t&uuml;histatud v&otilde;i saadetud';
$lang['notes'] = 'M&auml;rkmed';
$lang['notshipped'] = 'Saatmata';
$lang['num'] = 'Nr.';
$lang['online'] = 'on-line';
$lang['order'] = 'Tellimus';
$lang['orders'] = 'Tellimused';
$lang['order_confirm_form_templates'] = 'Confirm Order Templates';
$lang['order_details'] = 'Tellimuse detailid';
$lang['order_notes'] = 'Tellimuse m&auml;rkmed';
$lang['order_number'] = 'Arve';
$lang['order_processing'] = 'Tellimuse t&ouml;&ouml;tlemine';
$lang['order_statistics'] = 'Tellimuse statistika';
$lang['order_summary'] = 'Tellimuse kokkuv&otilde;te';
$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'Soodustus';
$lang['paid'] = 'Makstud';
$lang['payment_amount'] = 'Makse summa';
$lang['payment_approved'] = 'Vastu v&otilde;etud';
$lang['payment_cancelled'] = 'T&uuml;histatud';
$lang['payment_date'] = 'Makse kuup&auml;ev';
$lang['payment_declined'] = 'Tagasi l&uuml;katud';
$lang['payment_error'] = 'Viga';
$lang['payment_form_templates'] = 'Payment Form Templates';
$lang['payment_gateway_settings'] = 'Payment Gateway Settings';
$lang['payment_info'] = 'Makse informatsioon';
$lang['payment_method'] = 'Makse meetod';
$lang['payment_notprocessed'] = 'T&ouml;&ouml;tlemata';
$lang['payment_options'] = 'Makse valikud';
$lang['payment_other'] = 'Muu';
$lang['payment_pending'] = 'Pooleliolev';
$lang['payment_status'] = 'Makse staatus';
$lang['pending'] = 'Pooleliolev';
$lang['phone'] = 'Telefon';
$lang['popup_new_window'] = 'Ava arve uues aknas';
$lang['postinstall'] = 'The orders module has been successfully installed';
$lang['postuninstall'] = 'The orders module and all associated data has been removed';
$lang['post_order_msg'] = 'Post Order Message';
$lang['postal'] = 'Postiindeks';
$lang['preferences'] = 'Eelistused';
$lang['prevpage'] = '<';
$lang['price'] = 'Hind';
$lang['print_invoice'] = 'Prindi see arve';
$lang['procede_manual_checkout'] = 'J&auml;tka manuaalse kassaga';
$lang['process_manual_payment'] = 'Teosta manuaalne makse';
$lang['process_new_transaction'] = 'Process CreditCard Transaction through Gateway';
$lang['process_order'] = 'T&ouml;&ouml;tle tellimus';
$lang['product_id'] = 'Toote ID';
$lang['promotions_module'] = 'Promotions Module';
$lang['promotions_settings'] = 'Promotions Settings';
$lang['prompt_address_property_map'] = 'Address to FEU Property Map';
$lang['prompt_address_retrieval'] = 'Address Retrieval Method';
$lang['prompt_admin_invoice_template'] = 'Printable Invoice Template';
$lang['prompt_allow_creditcard_entry'] = 'Allow customer to enter credit card information';
$lang['prompt_billingpage'] = 'Page to assume that the billing form will be displayed on.  This is usually the page with your <code>{Orders}</code> tag.';
$lang['prompt_ccprocessing_module'] = 'Credit Card Processing Gateway';
$lang['prompt_confirmpage'] = 'Page to use for the confirmation form';
$lang['prompt_date_search_type'] = 'Filter Records that were ';
$lang['prompt_email'] = 'Emaili aadress';
$lang['prompt_encryption_key'] = 'Encryption Key';
$lang['prompt_forcessl'] = 'Redirect the page to HTTPS for input of payment info';
$lang['prompt_gateway_description'] = 'Description to send to the payment gateway';
$lang['prompt_invoice_message'] = 'Message to appear at the top of all invoices';
$lang['prompt_invoicepage'] = 'Page to use for the invoice display';
$lang['prompt_of'] = 'kokku';
$lang['prompt_ordernum_prefix'] = 'OrderNum Prefix';
$lang['prompt_page'] = 'Leht';
$lang['prompt_pagelimit'] = 'Tellimusi lehe kohta';
$lang['prompt_paymentpage'] = 'Page to use for the payment form';
$lang['prompt_permit_deletion'] = 'Allow deletion of orders';
$lang['prompt_process_cc_now'] = 'Process CreditCard Payment';
$lang['prompt_skip_invoice_page'] = 'J&auml;ta vahele arve lehek&uuml;lg';
$lang['prompt_store_creditcard_data'] = 'Permanently Store CreditCard Information';
$lang['prompt_template'] = 'Message Template';
$lang['prompt_username'] = 'Kasutajanimi';
$lang['proposed'] = 'Pakutud';
$lang['quantity'] = 'Kogus';
$lang['really_uninstall'] = 'Are you sure you really want to do this? Any data associated with this module will be lost if you procede';
$lang['records_matching_query'] = 'P&auml;ringule vastavate kirjete hulk';
$lang['regex'] = 'Regular Expression';
$lang['remember_last_address_used'] = 'Kasuta viimase tellimuse aadressi';
$lang['return'] = 'Tagasi';
$lang['require_group_membership'] = 'Require that all users that procede to the order stage be a member in this FEU Group';
$lang['security_settings'] = 'Turvalisuse seaded';
$lang['select_action'] = 'Vali tegevus';
$lang['select_one'] = 'Vali &uuml;ks';
$lang['select_invoice_template'] = 'Select Invoice Template';
$lang['send'] = 'Saada';
$lang['send_message'] = 'Saada sellele kliendile s&otilde;num';
$lang['sent'] = 'Saadetud';
$lang['ship_to'] = 'Saada';
$lang['shipped'] = 'Saadetud';
$lang['shipping'] = 'Saatmine';
$lang['shipping_address'] = 'Saatmise aadress';
$lang['shipping_info'] = 'Saatmise informatsioon';
$lang['shipping_info_if_different'] = 'Saatmise informatsioon <em>(kui erinev arve informatsioonist)</em>';
$lang['shipping_message'] = 'S&otilde;num seoses selle sihtkohaga';
$lang['shipping_module'] = 'Saatmise moodul';
$lang['shipping_settings'] = 'Saatmise seaded';
$lang['shipping_total'] = 'Saatmine kokku';
$lang['special_instructions'] = 'Spetsiaalsed instruktsioonid';
$lang['state/province'] = 'Maakond';
$lang['status'] = 'Olek';
$lang['subject'] = 'Teema';
$lang['submit'] = 'Saada';
$lang['submitted'] = 'Sisestatud';
$lang['submit_payment_info'] = 'Sisesta makse info';
$lang['subtotal'] = 'Vahesumma';
$lang['tax'] = 'Maks';
$lang['tax_module'] = 'Maksu moodul';
$lang['tax_settings'] = 'Maksu seaded';
$lang['template'] = 'Template';
$lang['template_name'] = 'Template Name';
$lang['thank_you_for_order'] = 'T&auml;name ostmast lehelt {sitename}';
$lang['title_adminemail_template'] = 'Administrator Email Template';
$lang['title_first_page'] = 'Mine esimesele lehele';
$lang['title_last_page'] = 'Mine viimasele lehele';
$lang['title_manage_order'] = 'Halda tellimust';
$lang['title_manual_process'] = 'Manual Transaction Processing';
$lang['title_next_page'] = 'Mine j&auml;rgmisele lehele';
$lang['title_prev_page'] = 'Mine eelmisele lehele';
$lang['title_useremail_template'] = 'User Email Template';
$lang['to'] = 'To';
$lang['total'] = 'Kokku';
$lang['tracking_num'] = 'Tracking Number';
$lang['transaction_id'] = 'Transaction Id';
$lang['transaction_successful'] = 'Payment processed successfully';
$lang['type'] = 'T&uuml;&uuml;p';
$lang['update_status'] = 'Update Status';
$lang['unit_price'] = '&Uuml;hiku hind';
$lang['unit_weight'] = '&Uuml;hiku kaal';
$lang['unknown'] = 'Tundmatu';
$lang['unlimited'] = 'Piiramatu';
$lang['username'] = 'Kasutajanimi';
$lang['user_email_template'] = 'User Email Template';
$lang['view'] = 'Vaata';
$lang['view_message'] = 'Vaata s&otilde;numit';
$lang['view_messages'] = 'Vaata selle tellimusega seotud s&otilde;numeid';
$lang['warning_https'] = '<strong>Warning!</strong> You are not using a secure (https) connection.  It is not recommended that you continue with this action without a secure connection.';
$lang['warning_manual_process'] = '<strong>Warning!</strong> This screen allows manual processing of credit card transactions using an online gateway.  Use caution!';
$lang['warning_no_ccprocessing_gateway'] = '<strong>Warning!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
$lang['warning_order_paid_in_full'] = '<strong>Warning!</strong> This order already appears to have been paid in full.';
$lang['warning_orderstatus_paid'] = '<strong>Warning!</strong> This order has already been paid.  You should not be processing a manual payment on this order';
$lang['warning_orderstatus_cancelled'] = '<strong>Warning!</strong> This order has been cancelled.  You should not be processing a manual payment on this order';
$lang['weight'] = 'Kaal';
$lang['within'] = 'viimase';
$lang['yes'] = 'Jah';
$lang['utma'] = '156861353.3215545266732019000.1241091787.1259062146.1259066226.193';
$lang['utmz'] = '156861353.1257873337.180.32.utmccn=(organic)|utmcsr=google|utmctr=how to secure cmsms|utmcmd=organic';
$lang['qca'] = '1240683615-58409973-79915303';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1259066226';
?>
